@@ -15,7 +15,6 @@ from cppython.data import Data
 from cppython.test.mock.generator import MockGenerator
 from cppython.test.mock.provider import MockProvider
 from cppython.test.mock.scm import MockSCM
-from cppython.test.schema import Variant
 
 
 class TestData:
@@ -27,9 +26,9 @@ class TestData:
         scope='session',
     )
     def fixture_data(
-        project_configuration: Variant[ProjectConfiguration],
-        pep621_configuration: Variant[PEP621Configuration],
-        cppython_local_configuration: Variant[CPPythonLocalConfiguration],
+        project_configuration: ProjectConfiguration,
+        pep621_configuration: PEP621Configuration,
+        cppython_local_configuration: CPPythonLocalConfiguration,
     ) -> Data:
         """Creates a mock plugins fixture.
 
@@ -46,13 +45,11 @@ class TestData:
 
         """
         logger = logging.getLogger()
-        builder = Builder(project_configuration.configuration, logger)
+        builder = Builder(project_configuration, logger)
 
         plugin_build_data = PluginBuildData(generator_type=MockGenerator, provider_type=MockProvider, scm_type=MockSCM)
 
-        return builder.build(
-            pep621_configuration.configuration, cppython_local_configuration.configuration, plugin_build_data
-        )
+        return builder.build(pep621_configuration, cppython_local_configuration, plugin_build_data)
 
     @staticmethod
     def test_sync(data: Data) -> None:
